@@ -1,10 +1,18 @@
 .extractResponse <- function(frm, dat) {
-# if (length(formula) == 3){
-        resp <- frm[[2]];
-        fdat <- eval(resp, envir=dat);
-#    }
-# else {stop("Formula missing Response") }
-    return(fdat)
+  # if (length(formula) == 3){
+  resp <- frm[[2]];
+  fdat <- eval(resp, envir=dat);
+  #    }
+  # else {stop("Formula missing Response") }
+  return(fdat)
+}
+
+.extractWeights <- function(call, dat) {
+  # if (length(formula) == 3){
+  fdat <- eval(call$weights, envir=dat);
+  #    }
+  # else {stop("Formula missing Response") }
+  return(fdat)
 }
 
 .normalize.initprobs.lm <- function (initprobs, p) {
@@ -68,7 +76,7 @@
 }
 
 
-bas.lm = function(formula, data, weights = NULL,
+bas.lm = function(formula, data, weights = NULL, na.action="na.omit",
     n.models=NULL,  prior="ZS-null", alpha=NULL,
     modelprior=beta.binomial(1,1),
     initprobs="Uniform", method="BAS", update=NULL, 
@@ -77,8 +85,19 @@ bas.lm = function(formula, data, weights = NULL,
     MCMC.iterations=NULL,
     lambda=NULL, delta=0.025, thin=1)  {
 
+  
   num.updates=10
   call = match.call()
+  
+ 
+  data = model.frame(formula, data, na.action=na.action)
+  n.NA = length(attr(data, 'na.action'))
+  
+  if (n.NA > 0) {
+    warning(paste("dropping ", as.character(n.NA), 
+                  "rows due to missing data"))
+  }
+  
   if ( !is.numeric(initprobs) && initprobs == "eplogp") {
       lm.obj = lm(formula, data, y=TRUE, x=TRUE)
       Y = lm.obj$y
